SecureCore

Trait SecureCore 

pub trait SecureCore: TurboCore { }
A marker trait to be applied to anything that implements TurboCore in order to indicate that a PRNG source is cryptographically secure, so being a CSPRNG.

This trait is provided as guidance only, and it is for the implementor to ensure that their PRNG source qualifies as cryptographically secure. Must be manually applied and is not an auto-trait.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> SecureCore for Box<T>
where T: TurboCore + SecureCore + ?Sized,

Available on crate feature alloc only.